.. rubric::

.. [AGY05] K. Andersen, G. Cornuéjols and Y. Li, Reduce-and-Split Cuts: Improving the Performance of Mixed-Integer Gomory Cuts. *Management Science*, 51, 1593-1732, 2005.

.. [Ande73] L.G. Anderson: A Simulation Study of some Dynamic Channel Assignment Algorithms in a High Capacity Mobile Telecommunications System. *IEEE Transactions on Communications*, 21:1294--1301. 1973.

.. [Appleg06] D.L. Applegate, R.E. Bixby, V. Chvatal and W.J. Cook. *The traveling salesman problem: a computational study*. Princeton university press. 2006.

.. [AtRa02] A Atamtürk, D Rajan. On splittable and unsplittable flow capacitated network design arc–set polyhedra. *Mathematical Programming*, 92(2), 315-333, 2002.

.. [Bala75] E. Balas. Facets of the knapsack polytope. *Mathematical Programming*, 8, 146-164, 1975.

.. [BCC93] E.Balas, S. Ceria and G. Cornuéjols. A lift-and-project cutting plane algorithm for mixed 0–1 programs. *Mathematical Programming*, 58, 295-324, 1993.

.. [BeFo76] E. Beale, J. Forrest. Global optimization using special ordered sets. *Mathematical Programming*, 10:52-69, 1976.

.. [BeTo70] E. Beale, J. Tomlin. Special facilities in a general mathematical programming system for non-convex problems. *OR*, 69:447-454, 1970.

.. [Capr96] A. Caprara and M. Fischetti. {0, 1/2}-Chvátal-Gomory cuts. *Mathematical Programming*, 74, 221-235, 1996.

.. [Dantz54] G. Dantzig,  R. Fulkerson and S. Johnson: Solution of a large-scale traveling-salesman problem. *Journal of the operations research society of America*, 2(4):393--410, 1954.

.. [DHL17I] J. H. Dunning and  M. Lubin. JuMP: a modeling language for mathematical optimization. SIAM Review, 59(2):295–320, 2017.

.. [FGL05] M. Fischetti, F. Glover, and A. Lodi. The feasibility pump. *Mathematical Programming*, 104(1):91–104, 2005.

.. [Fisch14] M. Fischetti, M. Monaci. Exploiting erraticism in search. *Operations Research*, 62:114--122, 2014.

.. [FiSa11] M. Fischetti, and D. Salvagnin. A relax-and-cut framework for Gomory mixed-integer cuts. *Mathematical Programming Computation*, 3(2), 79-102, 2011.

.. [Gomo69] R.E. Gomory. Some polyhedra related to combinatorial problems. *Linear Algebra and its Applications*, 2(4):451-558, 1969.

.. [Junge09] M. Jünger, T.M. Liebling, D. Naddef, G. Nemhauser, W.R. Pulleyblank, G. Reinelt, G. Rinaldi and Wolsey, L.A. *50 Years of integer programming 1958-2008: From the early years to the state-of-the-art*. Springer Science & Business Media. 2009.

.. [Kan60] L. V. Kantorovich. Mathematical methods of organizing and planning production. *Management science*, 6(4):366–422, 1960.

.. [LMM02] A. Lodi, S. Martello and M. Monaci. Two-dimensional packing problems: A survey. *European Journal of Operational Research*, 141(2):241-252, 2002.

.. [Mann60] A.S. Manne. On the job-shop scheduling problem. *Operations Research*, 8(2):219–223, 1960.

.. [Marc01] H. Marchand and L. Wolsey. Aggregation and Mixed Integer Rounding to Solve MIPs. *Operations Research*, 49(3), 325-468. 2001.

.. [Padb73] M.W. Padberg. On the facial structure of set packing polyhedra. *Mathematical Programming*, 5, 199-215, 1973.

.. [PWW69] A. Pritsker, L. Watters, and P. Wolfe. Multi-project scheduling with limited resources: a zero-one programming approach. *Management Science*, 16:93–108, 1969.

.. [Wols98] Wolsey, L.A. *Integer Programming*. Wiley-Interscience. 1998.
